<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:ns1="ns1"
	exclude-result-prefixes="exsl ns1"
	version="1.0">


	<!--
		Шаблон-контейнер. Предназначен для задания макета внутренних элементов с помощью присваемого ему класса.
		По умолчанию
	-->
	<xsl:template name="blocks">
		<xsl:param name="elements"/>
		<xsl:param name="display" select="'row'"/>
		<xsl:param name="columns"/>
		<xsl:param name="width"/>
		<xsl:param name="class"/>

		<div>
			<xsl:attribute name="class">
				<xsl:variable name="class-display">
					<xsl:choose>
						<xsl:when test="$display = 'row'">row</xsl:when>
						<xsl:when test="$display = 'columns' or $display = 'flex'">columns</xsl:when>
						<xsl:when test="$display = 'table'">table</xsl:when>
						<xsl:when test="$display = 'table-row'">table-row</xsl:when>
					</xsl:choose>
				</xsl:variable>

				<xsl:choose>
					<xsl:when test="not($class)">
						<xsl:value-of select="$display"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="concat($display, ' ', $class)"/>
					</xsl:otherwise>
				</xsl:choose>

			</xsl:attribute>
			<xsl:if test="$width">
				<xsl:attribute name="style">
					<xsl:text>width:</xsl:text><xsl:value-of select="$width"/>;
				</xsl:attribute>
			</xsl:if>


			<xsl:copy-of select="$elements"/>
		</div>
	</xsl:template>


	<xsl:template name="header">
		<xsl:param name="title"/>
		<xsl:param name="align">left</xsl:param>

		<xsl:if test="normalize-space($title)">
			<header class="header">
				<h1 class="title {$align}">
					<xsl:copy-of select="$title"/>
				</h1>
			</header>
		</xsl:if>
	</xsl:template>


	<!--
		Шаблон для создания заголовка и выделенного рамкой блока под ним
		@header
		@body - копирует в поток передаваемое содержимое
		@border
	-->
	<xsl:template name="section">
		<xsl:param name="header"/>
		<xsl:param name="body"/>
		<xsl:param name="border"/>
		<xsl:param name="class"/>
		<xsl:param name="style"/>

		<xsl:variable name="addClass">
			<xsl:if test="$class">
				<xsl:value-of select="concat(' ', $class)"/>
			</xsl:if>
		</xsl:variable>
		<section class="section{$addClass}">
			<xsl:if test="$style">
				<xsl:attribute name="style">
					<xsl:value-of select="$style"/>
				</xsl:attribute>
			</xsl:if>

			<xsl:call-template name="header">
				<xsl:with-param name="title" select="$header"/>
			</xsl:call-template>

			<xsl:if test="$body">
				<main class="{normalize-space(concat('wrapper ', $border))}">

					<xsl:copy-of select="$body"/>
				</main>
			</xsl:if>
		</section>
	</xsl:template>

	<xsl:template name="textOutput">
		<xsl:param name="text"/>
		<xsl:param name="lang" select="'ru'"/>
		<xsl:param name="labelNo" select="1"/>

		<xsl:variable name="inputText" select="exsl:node-set($text)/ns1:label[$labelNo]"/>

		<xsl:choose>
			<xsl:when test="$lang = 'ru'">
				<xsl:value-of select="$inputText/ns1:ru"/>
			</xsl:when>
			<xsl:when test="$lang = 'all'">
				<xsl:for-each select="$inputText/*">
					<span>
						<xsl:if test="local-name() = 'he'">
							<xsl:attribute name="class">rtl</xsl:attribute>
						</xsl:if>
						<xsl:attribute name="lang">
							<xsl:value-of select="local-name()"/>
						</xsl:attribute>
						<xsl:value-of select="."/>
					</span>
					<xsl:if test="position() != last()">
						<xsl:text> / </xsl:text>
						<xsl:text>&#10;</xsl:text>
					</xsl:if>
				</xsl:for-each>
			</xsl:when>
			<xsl:otherwise>
				<span>
					<xsl:if test="$lang = 'he'">
						<xsl:attribute name="class">rtl</xsl:attribute>
					</xsl:if>
					<xsl:attribute name="lang">
						<xsl:value-of select="$lang"/>
					</xsl:attribute>
					<xsl:value-of select="$inputText/*[local-name() = $lang]"/>
				</span>

			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="getInputType">
		<xsl:param name="values"/>

		<xsl:variable name="isNextSibling">
			<xsl:call-template name="isNextSibling">
				<xsl:with-param name="values" select="$values"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="$isNextSibling = 'true'">checkbox</xsl:when>
			<xsl:otherwise>radio</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="isNextSibling">
		<xsl:param name="values"/>
		<xsl:choose>
			<xsl:when test="$values = ''">
				<xsl:value-of select="false()"/>
			</xsl:when>
			<xsl:when test="$values/following-sibling::*[local-name() = local-name($values)]">
				<xsl:value-of select="true()"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="false()"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!--
		Шаблон для отображения чекбоксов (радиокнопок) в виде одной или нескольких колонок

	-->
	<xsl:template name="checkboxes">
		<xsl:param name="labels"/>
		<xsl:param name="values"/>
		<xsl:param name="label.position">right</xsl:param>
		<xsl:param name="label.width"/>
		<xsl:param name="values.direction">asc</xsl:param>
		<xsl:param name="values.start">0</xsl:param>
		<xsl:param name="display" select="'column'"/>
		<xsl:param name="columnsCount" select="1"/>
		<xsl:param name="fieldsetID" select="1"/>


		<xsl:variable name="inputType" select="'radio'"/>
		<xsl:variable name="labels.count" select="count(exsl:node-set($labels)/*)"/>

		<fieldset class="fieldset">
			<ul>
				<xsl:attribute name="class">
					<xsl:choose>
						<xsl:when test="$labels.count &gt; 2">checkbox-list checkboxes-column</xsl:when>
						<xsl:otherwise>checkbox-list checkboxes-row</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>

				<xsl:for-each select="exsl:node-set($labels)/*">

					<li class="checkbox-item">
						<label class="checkbox-label">

							<xsl:element name="input">
								<xsl:choose>
									<xsl:when test="number($values) = number($values)">
										<xsl:choose>
											<xsl:when
												test="(position() = $values + 1 and $values.direction = 'asc')
												or
												(position() = $labels.count - $values and $values.direction = 'desc')"
												>
												<xsl:attribute name="class">checkbox-input checked</xsl:attribute>
												<xsl:attribute name="checked">checked</xsl:attribute>
												<xsl:attribute name="value">
													<xsl:value-of select="$values"/>
												</xsl:attribute>
											</xsl:when>
											<xsl:otherwise>
												<xsl:attribute name="class">checkbox-input</xsl:attribute>
												<xsl:attribute name="value">
													<xsl:value-of select="$values"/>
												</xsl:attribute>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:when>
									<xsl:otherwise>

										<xsl:choose>
											<xsl:when test="$inputType = 'checkbox'">
												<xsl:if test="exsl:node-set($labels)/ns1:values/ns1:value[. = $values]">
													<xsl:attribute name="class">checkbox-input checked dev</xsl:attribute>
													<xsl:attribute name="checked">checked</xsl:attribute>
													<xsl:attribute name="value">
														<xsl:value-of select="$values"/>
													</xsl:attribute>
												</xsl:if>
											</xsl:when>
											<xsl:when test="$inputType = 'radio'">
												<xsl:variable name="index">
													<xsl:if test="normalize-space($values)">
														<xsl:value-of
															select="count(exsl:node-set($labels)/ns1:values/ns1:value[. = $values][1]/preceding-sibling::ns1:value) + 1"
														/>
													</xsl:if>
												</xsl:variable>

												<xsl:choose>
													<xsl:when test="$index = position()">
														<xsl:attribute name="class">checkbox-input checked dev</xsl:attribute>
														<xsl:attribute name="checked">checked</xsl:attribute>
														<xsl:attribute name="value">
															<xsl:value-of select="$values"/>
														</xsl:attribute>
													</xsl:when>
													<xsl:otherwise>
														<xsl:attribute name="class">checkbox-input</xsl:attribute>
														<xsl:attribute name="value">
															<xsl:value-of select="$values"/>
														</xsl:attribute>
													</xsl:otherwise>
												</xsl:choose>
											</xsl:when>
										</xsl:choose>

									</xsl:otherwise>
								</xsl:choose>

								<xsl:attribute name="type">
									<xsl:value-of select="$inputType"/>
								</xsl:attribute>
								<xsl:attribute name="name">
									<xsl:value-of select="concat('fieldset_', $inputType, '_', $fieldsetID)"/>
								</xsl:attribute>
								<span class="label-text-wrapper label-{$label.position}">
									<xsl:if test="$label.width">
										<xsl:attribute name="style">
											<xsl:text>width:</xsl:text><xsl:value-of select="$label.width"/>
										</xsl:attribute>
									</xsl:if>
									<!--&#160;&#160;-->
									<xsl:choose>
										<xsl:when test="ns1:ru">
											<xsl:value-of select="ns1:ru"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="."/>
										</xsl:otherwise>
									</xsl:choose>

								</span>

							</xsl:element>
						</label>
					</li>
				</xsl:for-each>
			</ul>
		</fieldset>
	</xsl:template>




	<xsl:template name="stringify">
		<xsl:param name="nodeset"/>
		<xsl:param name="delimeter" select="' '"/>
		<xsl:for-each select="exsl:node-set($nodeset)/*">
			<xsl:value-of select="."/>
			<xsl:if test="normalize-space(.) and not(position() = last())">
				<xsl:value-of select="$delimeter"/>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>

	<xsl:template name="ordered">
		<xsl:param name="nodeset"/>
		<xsl:param name="order"/>
		<xsl:param name="delimeter" select="' '"/>

		<xsl:variable name="number" select="substring-before($order, $delimeter)"/>

		<xsl:choose>
			<xsl:when test="normalize-space($number)">

				<xsl:if test="number($number) = number($number)">
					<xsl:value-of select="$nodeset/*[number($number)]"/>
					<xsl:value-of select="$delimeter"/>
					<xsl:call-template name="ordered">
						<xsl:with-param name="nodeset" select="$nodeset"/>
						<xsl:with-param name="order" select="substring-after($order, $delimeter)"/>
						<xsl:with-param name="delimeter" select="$delimeter"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="number($order) = number($order)">
					<xsl:value-of select="$nodeset/*[number($order)]"/>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>


	<!--
		Парный чекбокс (две радиокнопки)
		@node	- узел со значениями чекбоксов
		@labels - метки чекбоксов
	-->
	<xsl:template name="YesNoCheckboxes">
		<xsl:param name="value"/>
		<xsl:param name="labels">
			<label>Да</label>
			<label>Нет</label>
		</xsl:param>
		<xsl:param name="label.position">right</xsl:param>

		<xsl:call-template name="checkboxes">
			<xsl:with-param name="labels" select="$labels"/>
			<xsl:with-param name="values" select="$value"/>
			<xsl:with-param name="values.direction">desc</xsl:with-param>
			<xsl:with-param name="values.start">0</xsl:with-param>
			<xsl:with-param name="label.position" select="$label.position"/>
		</xsl:call-template>

	</xsl:template>

	<!--
		Шаблон строки вида: метка - значение
		@label
		@value
		@substring
		@display
	-->
	<!--
		Версию этого шаблона см. в универсальных
	-->
	<xsl:template name="label-value">
		<!--<xsl:param name="label">&#160;</xsl:param>-->
		<xsl:param name="label"/>
		<xsl:param name="value">&#160;</xsl:param>
		<xsl:param name="text"/><!-- depricated -->
		<xsl:param name="input"/>
		<xsl:param name="substring"/>
		<xsl:param name="display" select="'row'"/>
		<xsl:param name="label.width"/>
		<!--
		- Метка и значение;
		- Метка и пустое значение;
		- Нет метки и есть значение;
		- Нет ни метки ни значения.
		-->

		<xsl:choose>
			<xsl:when test="($label or $value) and not($substring)">
				<div class="{$display} label-value">
					<xsl:call-template name="label">
						<xsl:with-param name="label" select="$label"/>
						<xsl:with-param name="label.width" select="$label.width"/>
					</xsl:call-template>

					<xsl:call-template name="value">
						<xsl:with-param name="value" select="$value"/>
						<xsl:with-param name="input" select="$input"/>
						<xsl:with-param name="text" select="$text"/>
					</xsl:call-template>
				</div>
			</xsl:when>
			<xsl:when test="($value or $substring) and not($label)">

				<div class="value-substring">
					<xsl:call-template name="value">
						<xsl:with-param name="value" select="$value"/>
						<xsl:with-param name="input" select="$input"/>
						<xsl:with-param name="text" select="$text"/>
					</xsl:call-template>
					<i class="substring">
						<xsl:value-of select="$substring"/>
					</i>
				</div>
			</xsl:when>
		</xsl:choose>



	</xsl:template>

	<xsl:template name="value">
		<xsl:param name="value"/>
		<xsl:param name="input"/>
		<xsl:param name="text"/>

		<span>
			<xsl:choose>
				<xsl:when test="$value and not($input)">
					<xsl:attribute name="class">value</xsl:attribute>
					<xsl:value-of select="$value"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="class">input value</xsl:attribute>
					<xsl:choose>
						<xsl:when test="$input = 'text'">
							<input class="input-text-value" type="text" value="{$value}" name="value[]"/>
						</xsl:when>
						<xsl:when test="$input = 'textarea'">
							<textarea>&#160;</textarea>
						</xsl:when>
					</xsl:choose>

				</xsl:otherwise>
			</xsl:choose>
		</span>

	</xsl:template>



	<xsl:template name="label">
		<xsl:param name="label"/>
		<xsl:param name="label.width"/>

		<xsl:if test="$label">
			<span class="label">
				<xsl:if test="$label.width">
					<xsl:attribute name="style">width:<xsl:value-of select="$label.width"/></xsl:attribute>
				</xsl:if>
				<xsl:choose>
					<xsl:when test="normalize-space($label)">
						<xsl:copy-of select="$label"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>&#160;</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</span>
		</xsl:if>

	</xsl:template>


	<!--
		Шаблон строки вида: метка - составное значение (чекбоксы и т.п.)
		@label
		@value
		@substring
		@display
	-->
	<!--
		Предполагается объединить с предыдущим
	-->
	<xsl:template name="label-blocks-value">
		<xsl:param name="label"/>
		<xsl:param name="value"/>
		<xsl:param name="substring"/>
		<xsl:param name="display" select="'row'"/>

		<div class="label-blocks-value">
			<xsl:if test="$label">
				<div class="label" style="align-self: center;">
					<xsl:copy-of select="$label"/>
				</div>
			</xsl:if>
			<xsl:if test="$value">
				<div class="value">
					<xsl:copy-of select="$value"/>
				</div>
			</xsl:if>
		</div>

	</xsl:template>

	<xsl:template name="fromTo">
		<xsl:param name="from">&#160;</xsl:param>
		<xsl:param name="to">&#160;</xsl:param>

		<div class="row fromTo">
			<xsl:call-template name="label-value">
				<xsl:with-param name="label">с</xsl:with-param>
				<xsl:with-param name="value" select="$from"/>
			</xsl:call-template>
			<xsl:call-template name="label-value">
				<xsl:with-param name="label">по</xsl:with-param>
				<xsl:with-param name="value" select="$to"/>
			</xsl:call-template>
		</div>
	</xsl:template>


	<xsl:template name="one-row-values">
		<xsl:param name="entries"/>
		<xsl:param name="labels.width"/>
		<xsl:param name="values.width"/>
		<xsl:variable name="blocks" select="exsl:node-set($entries)"/>

		<table class="one-row-table">
			<colgroup>
				<xsl:for-each select="$blocks/*">
					<col>
						<xsl:choose>
							<xsl:when test="$labels.width">
								<xsl:attribute name="width">
									<xsl:value-of select="$labels.width"/>
								</xsl:attribute>
							</xsl:when>
						</xsl:choose>
					</col>
					<col>
						<xsl:choose>
							<xsl:when test="$values.width">
								<xsl:attribute name="width">
									<xsl:value-of select="$values.width"/>
								</xsl:attribute>
							</xsl:when>
						</xsl:choose>
					</col>
				</xsl:for-each>
			</colgroup>
			<tbody>
				<tr>
					<xsl:for-each select="$blocks/*">
						<td class="label" style="width:100px;">
							<xsl:value-of select="ns1:label"/>
						</td>
						<td style="width:230px;">

								<xsl:choose>
									<xsl:when test="normalize-space(ns1:text)">
										<xsl:attribute name="class">value</xsl:attribute>
										<xsl:value-of select="ns1:text"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="class">input value</xsl:attribute>
										<input class="input-text-value" type="text" value="{ns1:value}" name="value[]"/>
									</xsl:otherwise>
								</xsl:choose>

						</td>
					</xsl:for-each>
				</tr>
			</tbody>
		</table>
	</xsl:template>

	<xsl:template name="nodes-in-row">
		<xsl:param name="nodes"/>
		<xsl:param name="delimeter">, </xsl:param>

		<xsl:for-each select="$nodes">
			<xsl:value-of select="."/>
			<xsl:if test="following-sibling::*">
				<xsl:value-of select="$delimeter"/>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>

	<xsl:template name="emptyLines">
		<xsl:param name="count" select="1"/>

		<xsl:if test="$count &gt; 0">
			<hr class="line"/>
			<xsl:call-template name="emptyLines">
				<xsl:with-param name="count" select="$count - 1"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

	<!-- Дата в формате 17 декабря 2018-->
	<xsl:template name="Date2Text">
		<xsl:param name="pDate"/>
		<!-- Если равно 1 и дата пустая, то "пустое" значение принимает вид "  "           -->
		<!-- Если равно 0 и дата пустая, то "пустое" значение принимает вид "  "    20     -->
		<xsl:param name="pNo2000YearWhenEmpty" select="0"/>
		<xsl:param name="style" select="''"/>
		<xsl:choose>
			<!--Если дата пустая, то выводим "пустое" значение-->
			<xsl:when test="translate($pDate, ' ', '') = ''">
				<xsl:choose>
					<xsl:when test="$pNo2000YearWhenEmpty = '1'">
						<span class="{$style}">&quot;&#160;&#160;&#160;&#160;&#160;&quot;</span>
						<span class="{$style}">&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;</span>
						<span class="{$style}">&#160;&#160;&#160;&#160;&#160;&#160;&#160;</span>
					</xsl:when>
					<xsl:otherwise>
						<span class="{$style}">&quot;&#160;&#160;&#160;&#160;&#160;&quot;</span>
						<span class="{$style}">&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;</span>
						<span class="{$style}">20&#160;&#160;&#160;&#160;&#160;</span>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="dateText" select="string($pDate)"/>
				<xsl:variable name="month" select="substring($dateText, 6, 2)"/>
				<span class="{$style}"><xsl:value-of select="concat('&quot;', substring($dateText, 9, 2), '&quot;')"/></span>
				<span class="{$style}">
					<xsl:choose>
						<xsl:when test="$month = '01'"> января </xsl:when>
						<xsl:when test="$month = '02'"> февраля </xsl:when>
						<xsl:when test="$month = '03'"> марта </xsl:when>
						<xsl:when test="$month = '04'"> апреля </xsl:when>
						<xsl:when test="$month = '05'"> мая </xsl:when>
						<xsl:when test="$month = '06'"> июня </xsl:when>
						<xsl:when test="$month = '07'"> июля </xsl:when>
						<xsl:when test="$month = '08'"> августа </xsl:when>
						<xsl:when test="$month = '09'"> сентября </xsl:when>
						<xsl:when test="$month = '10'"> октября </xsl:when>
						<xsl:when test="$month = '11'"> ноября </xsl:when>
						<xsl:when test="$month = '12'"> декабря </xsl:when>
					</xsl:choose>
				</span>
				<span class="{$style}">
					<xsl:value-of select="substring($dateText, 1, 4)"/>
				</span>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:variable name="l-rus" select="'абвгдеёзийклмнопрстуфхьыъэАБВГДЕЁЗИЙКЛМНОПРСТУФХЬЫЪЭ'"/>
	<xsl:variable name="l-trans" select="'abvgdeеzijklmnoprstufh`y`eABVGDEEZIJKLMNOPRSTUFH`Y`E'"/>

	<xsl:template name="translit" match="text()">
		<xsl:param name="str"/>
		<xsl:variable name="q1" select="$str"/>
		<xsl:variable name="q2" select="normalize-space(translate($q1,$l-rus,$l-trans))"/>
		<xsl:variable name="q3">
			<xsl:call-template name="replace">
				<xsl:with-param name="str" select="$q2"/>
				<xsl:with-param name="search-for" select="'ж'"/>
				<xsl:with-param name="replace-to" select="'zh'"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="q4">
			<xsl:call-template name="replace">
				<xsl:with-param name="str" select="$q3"/>
				<xsl:with-param name="search-for" select="'ш'"/>
				<xsl:with-param name="replace-to" select="'sh'"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="q5">
			<xsl:call-template name="replace">
				<xsl:with-param name="str" select="$q4"/>
				<xsl:with-param name="search-for" select="'ю'"/>
				<xsl:with-param name="replace-to" select="'yu'"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="q6">
			<xsl:call-template name="replace">
				<xsl:with-param name="str" select="$q5"/>
				<xsl:with-param name="search-for" select="'я'"/>
				<xsl:with-param name="replace-to" select="'ya'"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="q7">
			<xsl:call-template name="replace">
				<xsl:with-param name="str" select="$q6"/>
				<xsl:with-param name="search-for" select="'ц'"/>
				<xsl:with-param name="replace-to" select="'ts'"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="q8">
			<xsl:call-template name="replace">
				<xsl:with-param name="str" select="$q7"/>
				<xsl:with-param name="search-for" select="'ч'"/>
				<xsl:with-param name="replace-to" select="'ch'"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:value-of select="$q8"/>
	</xsl:template>

	<xsl:template name="replace" match="text()">
		<xsl:param name="str"/>
		<xsl:param name="search-for"/>
		<xsl:param name="replace-to"/>
		<xsl:choose>
			<xsl:when test="contains($str, $search-for)">
				<xsl:value-of select="substring-before($str, $search-for)"/>
				<xsl:copy-of select="$replace-to"/>
				<xsl:call-template name="replace">
					<xsl:with-param name="str" select="substring-after($str, $search-for)"/>
					<xsl:with-param name="search-for" select="$search-for"/>
					<xsl:with-param name="replace-to" select="$replace-to"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$str"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

</xsl:stylesheet>
